#
# spec file for package bees
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           bees
Version:        0.10
Release:        2.3
Summary:        Best-Effort Extent-Same, a btrfs deduplication agent
License:        GPL-3.0-only
Group:          System/Filesystems
URL:            https://github.com/Zygo/bees
Source:         https://github.com/Zygo/bees/archive/refs/tags/v%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  libbtrfs-devel
BuildRequires:  libuuid-devel
BuildRequires:  make
%if 0%{?suse_version} == 1500 && 0%{?sle_version} > 150200
BuildRequires:  gcc13-c++
%else
BuildRequires:  gcc-c++
%endif

%description
bees is a block-oriented userspace deduplication agent designed for large btrfs
filesystems. It is an offline dedupe combined with an incremental data scan
capability to minimize time data spends on disk from write to dedupe.

Hilights:

* Space-efficient hash table and matching algorithms - can use as little as 1
  GB hash table per 10 TB unique data (0.1GB/TB)
* Daemon incrementally dedupes new data using btrfs tree search
* Works with btrfs compression - dedupe any combination of compressed and uncompressed files
* Persistent hash table for rapid restart after shutdown
* Whole-filesystem dedupe - including snapshots
* Constant hash table size - no increased RAM usage if data set becomes larger
* Works on live data - no scheduled downtime required
* Automatic self-throttling based on system load

%prep
%autosetup -p1

%build
%if 0%{?suse_version} == 1500 && 0%{?sle_version} > 150200
export CC=gcc-13
export CXX=g++-13
%endif
cat >localconf <<-EOF
	SYSTEMD_SYSTEM_UNIT_DIR=%{_unitdir}
	LIBEXEC_PREFIX=%{_bindir}
	LIB_PREFIX=%{_libdir}
	PREFIX=%{_prefix}
	LIBDIR=%{_libdir}
	DEFAULT_MAKE_TARGET=all
EOF

%make_build BEES_VERSION=%{version}

%install
%make_install

%files
%license COPYING
%doc README.md
%{_bindir}/bees
%{_sbindir}/beesd
%{_unitdir}/beesd@.service
%dir %{_sysconfdir}/bees
%{_sysconfdir}/bees/beesd.conf.sample

%changelog
* Thu Mar  7 2024 Max Lin <mlin@suse.com>
- Fix build fail with gcc7 on Leap 15
  * Use gcc13 on compilation
* Mon Jul 24 2023 Frederic Crozat <fcrozat@suse.com>
- Update to 0.10:
  * Update kernel bugs list to 6.4.1
  * Update docs
  * Build fixes for GCC 13 and clang 16
- Drop avoid-swap.patch, no longer needed.
* Tue Apr  4 2023 Dirk Müller <dmueller@suse.com>
- update to 0.9.3:
  * roots: don't share a RootFetcher between threads
  * seeker: fix the test for ILP32 platforms
  * reduce memory usage with long-running work items
  * allow BtrfsIoctlLogicalInoArgs to be reused, remove virtual methods
  * create a Pool of BtrfsIoctlLogicalInoArgs objects
- add avoid-swap.patch to fix build with gcc 13
* Sun Mar 12 2023 Björn Bidar <bjorn.bidar@thaodan.de>
- Removed patch: fix-Makefile-version.diff, replaced with make parameter.
* Tue Feb 14 2023 Avinesh Kumar <avinesh.kumar@suse.com>
- update to 0.9.1:
  * Fix the install target.
  * Makefile: also drop fiemap and fiewalk from main Makefile
- update to 0.9:
  - Highlights:
  * Work around a kernel bug which can be triggered by running the
    LOGICAL_INO ioctl and dedupe on the same extent at the same time.
  * Prevent worker threads from being blocked by extent and inode
    locks.  Defer the blocked item and find something else for that
    worker thread to do.
  * Fix the labelling of threads so they aren't all "task_consumer".
  * Speed up SIGTERM process termination to have a better chance of
    flushing the hash table and crawl state to $BEESHOME before the
    process is killed by a service timeout.
  * Reduce the hash table writeback rate to 128K/s.
  * Reduce the interval between crawl restarts to one transid.
  * Add 'recent' scan mode, which dedupes new data in fully scanned
    subvols instead of waiting for every old subvol to be scanned.
  * Better behavior when there are write errors in $BEESHOME.
  * Drop the unused and obsolete `fiemap` and `fiewalk` binaries.
* Mon Dec  5 2022 Dirk Müller <dmueller@suse.com>
- update to 0.8:
  * fs: make dedupe work again after a really unfortunate build fix
* Wed Oct 19 2022 dsterba@suse.cz
- update to 0.7 git 5953ea6d3c5646 (20221025)
- build fixes
- Removed patch: 0001-fs-fix-FIEMAP_MAX_OFFSET-type-silliness-in-fiemap.h.patch
* Sun Sep  4 2022 dsterba@suse.cz
- Added patch: 0001-fs-fix-FIEMAP_MAX_OFFSET-type-silliness-in-fiemap.h.patch
  (fix build on ppc64le)
* Tue Oct  5 2021 dsterba@suse.cz
- Update to 0.7
  - Highlights:
  * Remove 8-CPU thread limit
  * Add kernel bugs reference table to docs
  * Workarounds for btrfs send and balance issues
  * Reduce the number of temporary inodes created
  * Use posix_fadvise to optimize page cache usage
  * Use private namespace for mounts under systemd
  * Assorted bug fixes and small performance improvements
  * SIGTERM handler to save crawl state, hash table, and exit
  * Higher ref limits per extent on kernels with LOGICAL_INO_V2
  - Build dependency changes:
  * Convert docs to Github Flavored Markdown
  * Updates for new compilers including clang
  * Remove dependencies on libbtrfs-dev and uuid-dev
  * Remove unversioned `libcrucible.so` shared library
* Wed May 12 2021 dsterba@suse.cz
- Update to 0.6.5
  - Make clang builds work.
- Update to 0.6.4
  - Fix a bug that was causing bees to stop deduping.
- spec: remove empty sections, unify make
* Sun Sep 13 2020 dsterba@suse.cz
- initial import 0.6.3
  Added patch: fix-Makefile-version.diff
